{-# LANGUAGE TemplateHaskell #-}

foo = foo

-- \|# ${
